.. _utilipy-fitting:

***************************
Fitting (`utilipy.fitting`)
***************************

.. currentmodule:: utilipy.data_utils.fitting



Reference/API
=============

.. automodapi:: utilipy.data_utils.fitting
